# Yapstone::EvidencesApi

All URIs are relative to *https://api-prod-sandbox.yapstone.com/v1/dispute*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_file**](EvidencesApi.md#create_file) | **POST** /evidences/{id}/files | Update a dispute evidences
[**create_text**](EvidencesApi.md#create_text) | **POST** /evidences/{id}/text | Update a dispute evidences
[**delete_file**](EvidencesApi.md#delete_file) | **DELETE** /files/{id} | Get the evidence by it&#39;s id
[**delete_text**](EvidencesApi.md#delete_text) | **DELETE** /text/{id} | Get the evidence by it&#39;s id
[**get_evidence**](EvidencesApi.md#get_evidence) | **GET** /evidences/{id} | Get the evidence by it&#39;s id
[**get_file_content_by_id**](EvidencesApi.md#get_file_content_by_id) | **GET** /files/{id}/content | Get file content by file evidence id



## create_file

> CompositeFileEvidence create_file(id, evidence_category, evidence_type, file)

Update a dispute evidences

### Example

```ruby
# load the gem
require 'yapstone-disputes'
# setup authorization
Yapstone.configure do |config|
  # Configure API key authorization: Bearer
  config.api_key['Authorization'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Authorization'] = 'Bearer'
end

api_instance = Yapstone::EvidencesApi.new
id = 'id_example' # String | Primary key for a single evidence record (assigned by YapStone)
evidence_category = 'evidence_category_example' # String | 
evidence_type = 'evidence_type_example' # String | 
file = File.new('/path/to/file') # File | file to upload

begin
  #Update a dispute evidences
  result = api_instance.create_file(id, evidence_category, evidence_type, file)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling EvidencesApi->create_file: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| Primary key for a single evidence record (assigned by YapStone) | 
 **evidence_category** | **String**|  | 
 **evidence_type** | **String**|  | 
 **file** | **File**| file to upload | 

### Return type

[**CompositeFileEvidence**](CompositeFileEvidence.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: multipart/form-data
- **Accept**: application/json


## create_text

> CompositeTextEvidence create_text(id, composite_text_evidence)

Update a dispute evidences

### Example

```ruby
# load the gem
require 'yapstone-disputes'
# setup authorization
Yapstone.configure do |config|
  # Configure API key authorization: Bearer
  config.api_key['Authorization'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Authorization'] = 'Bearer'
end

api_instance = Yapstone::EvidencesApi.new
id = 'id_example' # String | Primary key for a single evidence record (assigned by YapStone)
composite_text_evidence = Yapstone::CompositeTextEvidence.new # CompositeTextEvidence | Text evidence to be created

begin
  #Update a dispute evidences
  result = api_instance.create_text(id, composite_text_evidence)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling EvidencesApi->create_text: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| Primary key for a single evidence record (assigned by YapStone) | 
 **composite_text_evidence** | [**CompositeTextEvidence**](CompositeTextEvidence.md)| Text evidence to be created | 

### Return type

[**CompositeTextEvidence**](CompositeTextEvidence.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## delete_file

> delete_file(id)

Get the evidence by it's id

Get the evidence by it's id 

### Example

```ruby
# load the gem
require 'yapstone-disputes'
# setup authorization
Yapstone.configure do |config|
  # Configure API key authorization: Bearer
  config.api_key['Authorization'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Authorization'] = 'Bearer'
end

api_instance = Yapstone::EvidencesApi.new
id = 'id_example' # String | Id of the file

begin
  #Get the evidence by it's id
  api_instance.delete_file(id)
rescue Yapstone::ApiError => e
  puts "Exception when calling EvidencesApi->delete_file: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| Id of the file | 

### Return type

nil (empty response body)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## delete_text

> delete_text(id)

Get the evidence by it's id

Get the evidence by it's id 

### Example

```ruby
# load the gem
require 'yapstone-disputes'
# setup authorization
Yapstone.configure do |config|
  # Configure API key authorization: Bearer
  config.api_key['Authorization'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Authorization'] = 'Bearer'
end

api_instance = Yapstone::EvidencesApi.new
id = 'id_example' # String | Id of the evidence

begin
  #Get the evidence by it's id
  api_instance.delete_text(id)
rescue Yapstone::ApiError => e
  puts "Exception when calling EvidencesApi->delete_text: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| Id of the evidence | 

### Return type

nil (empty response body)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_evidence

> CompositeEvidenceResponse get_evidence(id)

Get the evidence by it's id

Get the evidence by it's id 

### Example

```ruby
# load the gem
require 'yapstone-disputes'
# setup authorization
Yapstone.configure do |config|
  # Configure API key authorization: Bearer
  config.api_key['Authorization'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Authorization'] = 'Bearer'
end

api_instance = Yapstone::EvidencesApi.new
id = 'id_example' # String | Id of the evidene

begin
  #Get the evidence by it's id
  result = api_instance.get_evidence(id)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling EvidencesApi->get_evidence: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| Id of the evidene | 

### Return type

[**CompositeEvidenceResponse**](CompositeEvidenceResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_file_content_by_id

> Object get_file_content_by_id(id)

Get file content by file evidence id

Returns a file evidence's content

### Example

```ruby
# load the gem
require 'yapstone-disputes'
# setup authorization
Yapstone.configure do |config|
  # Configure API key authorization: Bearer
  config.api_key['Authorization'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Authorization'] = 'Bearer'
end

api_instance = Yapstone::EvidencesApi.new
id = 'id_example' # String | File evidence id

begin
  #Get file content by file evidence id
  result = api_instance.get_file_content_by_id(id)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling EvidencesApi->get_file_content_by_id: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| File evidence id | 

### Return type

**Object**

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/*

